RowwiseMult - LatentLego

Skip to content

# RowwiseMult

### `latent.layers.RowwiseMult`

Performs row-wise multiplication between input vectors.

#### `__init__(self, name=None)` `special`

Parameters:

Name | Type | Description | Default
--- | --- | --- | ---
`name` | `str` | String indicating the name of the layer. | `None`

#### `call(self, inputs)`

This is where the layer's logic lives.

Note here that `call()` method in `tf.keras` is little bit different from `keras` API. In `keras` API, you can pass support masking for layers as additional arguments. Whereas `tf.keras` has `compute_mask()` method to support masking.

Parameters:

Name | Type | Description | Default
--- | --- | --- | ---
`inputs` | `` | Input tensor, or list/tuple of input tensors. | required
`**kwargs` | `` | Additional keyword arguments. Currently unused. | required

Returns:

Type | Description
--- | ---
`` | A tensor or list/tuple of tensors.